(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     88337,       2510]
NotebookOptionsPosition[     79155,       2353]
NotebookOutlinePosition[     79563,       2369]
CellTagsIndexPosition[     79520,       2366]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Dispersive Analysis of the Pion Transition Form Factor", "Title",
 CellChangeTimes->{{3.829827190760186*^9, 
  3.829827207284837*^9}},ExpressionUUID->"93ce0d35-dd3a-459f-a7f3-\
9ffe3063cc0e"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
     "We", " ", "confirm", " ", "some", " ", "calculations", " ", "from"}], 
     " ", "<", 
     RowBox[{"https", ":"}]}], "//", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"arxiv", ".", "org"}], "/", "pdf"}], "/", 
      RowBox[{"1410.4691", ".", "pdf"}]}], ">"}]}], ",", " ", 
   RowBox[{
   "see", " ", "also", " ", "the", " ", "corresponding", " ", "handwritten", 
    " ", 
    RowBox[{"notes", ".", " ", "The"}], " ", 
    SuperscriptBox["e", "+"], 
    SuperscriptBox["e", "-"], " ", "calculation", " ", "is", " ", "done", " ",
     "on", " ", "a", " ", "separate", " ", 
    RowBox[{"sheet", "/", "in"}], " ", "a", " ", "different", " ", 
    RowBox[{"NB", "."}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.829827209186736*^9, 3.829827220882801*^9}, {
  3.830086833344689*^9, 
  3.830086861830296*^9}},ExpressionUUID->"84020e94-1db8-42af-a5c8-\
6de4d0279412"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"RESET", " ", 
    RowBox[{"KERNEL", "!"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"<<", "FeynCalc`"}]}]], "Input",
 CellChangeTimes->{{3.829982539165934*^9, 3.8299825398041277`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"2809d165-2007-4043-b67d-18f0e7d2f2a6"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"FeynCalc \"\>", "Text",
     StripOnInput->False,
     FontWeight->Bold], "\[InvisibleSpace]", 
    StyleBox["\<\"9.3.1 (stable version). For help, use the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"documentation", " ", "center"}],
       BaseStyle->"Link",
       ButtonData:>"paclet:FeynCalc/",
       ButtonNote->"paclet:FeynCalc/"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\", check out the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["wiki",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" or visit the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"forum", "."}],
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/discussions"], None},
       ButtonNote->"http://www.feyncalc.org/forum/"],
      DisplayForm], "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["FeynCalc ", "Text", Bold], 
    Style["9.3.1 (stable version). For help, use the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "documentation center", BaseStyle -> "Link", ButtonData :> 
       "paclet:FeynCalc/", ButtonNote -> "paclet:FeynCalc/"]], "Text"], 
    Style[", check out the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["wiki", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None}, BaseStyle -> 
       "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" or visit the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["forum.", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/discussions"], None}, 
       BaseStyle -> "Hyperlink", ButtonNote -> 
       "http://www.feyncalc.org/forum/"]], "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.829982556083912*^9, 3.830086771592136*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"273b65a6-5f0e-47e6-aaf8-21811d06a14d"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"To save your and our time, please check our \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["FAQ",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki/FAQ"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" for answers to some common FeynCalc questions.\"\>", "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["To save your and our time, please check our ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["FAQ", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki/FAQ"], None}, 
       BaseStyle -> "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" for answers to some common FeynCalc questions.", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.829982556083912*^9, 3.8300867715970078`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"ecd34515-9d8f-4c55-a03e-e98fd91d5567"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"See also the supplied \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"examples", "."}],
       BaseStyle->"Hyperlink",
       ButtonFunction:>SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]],
       Evaluator->Automatic,
       Method->"Preemptive"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" If you use FeynCalc in your research, please cite\"\>", 
     "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["See also the supplied ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "examples.", BaseStyle -> "Hyperlink", ButtonFunction :> SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]], Evaluator -> 
       Automatic, Method -> "Preemptive"]], "Text"], 
    Style[" If you use FeynCalc in your research, please cite", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.829982556083912*^9, 3.830086771598785*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"7d6a6b06-e0e3-457e-8f13-8198c8975ac7"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, \
Comput.Phys.Commun. 256 (2020) 107478, arXiv:2001.04407.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.829982556083912*^9, 3.830086771600692*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"1b5bcf7c-b03b-42e5-b0f6-49e15cde755e"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, \
Comput.Phys.Commun. 207 (2016) 432-444, arXiv:1601.01167.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.829982556083912*^9, 3.830086771602994*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"6e9ebe7a-7040-4f8d-8b4f-f0b1e0a6ba83"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] R. Mertig, M. B\[ODoubleDot]hm, and A. Denner, \
Comput. Phys. Commun. 64 (1991) 345-359.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.829982556083912*^9, 3.830086771605929*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"ef05325c-13a2-4544-9f4c-a69aa4aa36cb"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Gamma]", "*"], "\[Rule]", " ", 
    RowBox[{"3", "\[Pi]"}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "7e67bbd2-27a9-4db1-a971-bad624f03d15"],
 " Amplitude"
}], "Section",
 CellChangeTimes->{{3.8300867979081297`*^9, 
  3.8300868122929497`*^9}},ExpressionUUID->"7e654cb2-248a-41b6-b95f-\
d61ef179bdca"],

Cell[CellGroupData[{

Cell["Kinematics", "Subsection",
 CellChangeTimes->{{3.8299826791386557`*^9, 
  3.829982686860298*^9}},ExpressionUUID->"ee42434f-6dde-4689-8939-\
f31ef28d34db"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Useful", " ", "functions", " ", "and", " ", 
    RowBox[{"variables", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]\[Pi]", "=", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{"4", 
         SuperscriptBox["M\[Pi]", "2"]}], "s"]}]]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]", "[", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"], "+", 
      SuperscriptBox["z", "2"], "-", 
      RowBox[{"2", "x", " ", "y"}], "-", 
      RowBox[{"2", "x", " ", "z"}], "-", 
      RowBox[{"2", "y", " ", "z"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.829982689463653*^9, 3.829982732386142*^9}, {
  3.829983329943492*^9, 3.8299833302269506`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"3ac2013f-691e-4b7c-b6a4-7b61ded813ab"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Energy", " ", "and", " ", "momentum", " ", "of", " ", "the", " ", 
     "initial"}], "-", 
    RowBox[{"state", " ", "photon", " ", "and", " ", "the", " ", "final"}], 
    "-", 
    RowBox[{"state", " ", 
     RowBox[{
      SuperscriptBox["\[Pi]", "0"], "."}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      SqrtBox["s"], "\[Equal]", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["q", "2"]}]], "-", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["M\[Pi]", "2"]}]]}]}], ",", "p"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p1", "=", 
     FractionBox[
      SqrtBox[
       RowBox[{"\[Lambda]", "[", 
        RowBox[{"s", ",", 
         SuperscriptBox["q", "2"], ",", 
         SuperscriptBox["M\[Pi]", "2"]}], "]"}]], 
      RowBox[{"2", 
       SqrtBox["s"]}]]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["p1", "2"], "+", 
       SuperscriptBox["q", "2"]}]], "//", "PowerExpand"}], "//", "Simplify"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["p1", "2"], "+", 
       SuperscriptBox["M\[Pi]", "2"]}]], "//", "PowerExpand"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E\[Gamma]", "=", 
     FractionBox[
      RowBox[{
       SuperscriptBox["q", "2"], "+", "s", "-", 
       SuperscriptBox["M\[Pi]", "2"]}], 
      RowBox[{"2", 
       SqrtBox["s"]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E\[Pi]0", "=", 
     FractionBox[
      RowBox[{
       SuperscriptBox["q", "2"], "-", "s", "-", 
       SuperscriptBox["M\[Pi]", "2"]}], 
      RowBox[{"2", 
       SqrtBox["s"]}]]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8299827593543177`*^9, 3.8299827798226547`*^9}, {
  3.829982908132409*^9, 3.8299829160626383`*^9}, {3.829982978590568*^9, 
  3.8299831459974623`*^9}, {3.829983189019886*^9, 3.829983248464539*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"4c9aa8a3-5f60-4ded-8ecf-f4e5ab1964bf"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        SqrtBox[
         RowBox[{
          SuperscriptBox["M\[Pi]", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["M\[Pi]", "2"], " ", 
           SuperscriptBox["q", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["M\[Pi]", "2"], " ", "s"}], "+", 
          SuperscriptBox["q", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["q", "2"], " ", "s"}], "+", 
          SuperscriptBox["s", "2"]}]], 
        RowBox[{"2", " ", 
         SqrtBox["s"]}]]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      FractionBox[
       SqrtBox[
        RowBox[{
         SuperscriptBox["M\[Pi]", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["M\[Pi]", "2"], " ", 
          SuperscriptBox["q", "2"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["M\[Pi]", "2"], " ", "s"}], "+", 
         SuperscriptBox["q", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["q", "2"], " ", "s"}], "+", 
         SuperscriptBox["s", "2"]}]], 
       RowBox[{"2", " ", 
        SqrtBox["s"]}]]}], "}"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.829983026664456*^9, {3.829983130930044*^9, 3.8299831462721233`*^9}, {
   3.829983190763612*^9, 3.8299831995857058`*^9}, 3.82998325268714*^9, 
   3.8300867721051483`*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"5268f882-fbcb-4f44-aa74-286518434564"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   SqrtBox[
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["M\[Pi]", "2"]}], "+", 
        SuperscriptBox["q", "2"], "+", "s"}], ")"}], "2"], "s"]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.829983026664456*^9, {3.829983130930044*^9, 3.8299831462721233`*^9}, {
   3.829983190763612*^9, 3.8299831995857058`*^9}, 3.82998325268714*^9, 
   3.8300867721376667`*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"e47306e2-45da-4931-aa20-d694696d1300"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   SqrtBox[
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M\[Pi]", "2"], "-", 
        SuperscriptBox["q", "2"], "+", "s"}], ")"}], "2"], "s"]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.829983026664456*^9, {3.829983130930044*^9, 3.8299831462721233`*^9}, {
   3.829983190763612*^9, 3.8299831995857058`*^9}, 3.82998325268714*^9, 
   3.830086772187461*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"7f6ac029-8b1c-4d02-b7ed-4b82f3cab11d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Energy", " ", "and", " ", "momentum", " ", "of", " ", "the", " ", 
     "final"}], "-", 
    RowBox[{"state", " ", 
     SuperscriptBox["\[Pi]", "+"], " ", "and", " ", 
     RowBox[{
      SuperscriptBox["\[Pi]", "-"], "."}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      SqrtBox["s"], "\[Equal]", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["M\[Pi]", "2"]}]], "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["M\[Pi]", "2"]}]]}]}], ",", "p"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p2", "=", 
     RowBox[{
      FractionBox[
       SqrtBox["s"], "2"], "\[Sigma]\[Pi]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["p2", "2"], "+", 
       SuperscriptBox["M\[Pi]", "2"]}]], "//", "PowerExpand"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E\[Pi]p", "=", 
     FractionBox[
      SqrtBox["s"], "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E\[Pi]m", "=", 
     FractionBox[
      SqrtBox["s"], "2"]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.829983258848196*^9, 3.8299833772052603`*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"0d976fc8-d16c-4fff-97bf-d3dc400cc467"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SqrtBox[
        RowBox[{"s", "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["M\[Pi]", "2"]}]}]]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SqrtBox[
        RowBox[{"s", "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["M\[Pi]", "2"]}]}]]}]}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.829983296147917*^9, {3.829983354403788*^9, 3.829983382437681*^9}, 
   3.830086772245235*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"596cddea-c1fd-4b99-8c3d-55e9438beff0"],

Cell[BoxData[
 FormBox[
  FractionBox[
   SqrtBox["s"], "2"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.829983296147917*^9, {3.829983354403788*^9, 3.829983382437681*^9}, 
   3.8300867722479353`*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"65d6c7f6-9353-44b8-955a-002fdc323022"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Including the relative Scattering Angle of the s - channel", \
"Subsection",
 CellChangeTimes->{{3.8299834010216703`*^9, 3.829983418162595*^9}, {
  3.8299834971010437`*^9, 
  3.82998350329902*^9}},ExpressionUUID->"63056678-6135-4f39-b2b6-\
9210ee4bd9c5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Note", " ", "that", " ", "for", " ", "s"}], ",", " ", 
    RowBox[{
     RowBox[{"we", " ", "can", " ", "use", " ", "s"}], "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["p", "+"], "+", 
         SubscriptBox["p", "-"]}], ")"}], "2"], " ", "to", " ", "define", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["p", "+"], "\[CenterDot]", 
         SubscriptBox["p", "-"]}], ")"}], "."}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"E\[Pi]p", "*", "E\[Pi]m"}], "+", 
     RowBox[{"p2", "*", "p2"}]}], "//", "Simplify"}], "\[IndentingNewLine]", 
   RowBox[{
    FractionBox[
     RowBox[{"s", "-", 
      RowBox[{"SP", "[", "pp", "]"}], "-", 
      RowBox[{"SP", "[", "pm", "]"}]}], "2"], "//", "Simplify"}]}]}]], "Input",\

 CellChangeTimes->{{3.829983522747414*^9, 3.8299836638419647`*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"3eedcbfc-4366-459d-9864-e3b9a141b64c"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"s", "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["M\[Pi]", "2"]}]}], ")"}]}], TraditionalForm]], "Output",\

 CellChangeTimes->{{3.829983557379814*^9, 3.829983592740632*^9}, 
   3.829983639391541*^9, 3.830086772329056*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"fbc2d560-8ade-4aca-bfa7-b0cfe97e2938"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FormBox[
       SuperscriptBox[
        FormBox[
         OverscriptBox[
          FormBox["pm",
           TraditionalForm], "_"],
         TraditionalForm], "2"],
       TraditionalForm]}], "-", 
     FormBox[
      SuperscriptBox[
       FormBox[
        OverscriptBox[
         FormBox["pp",
          TraditionalForm], "_"],
        TraditionalForm], "2"],
      TraditionalForm], "+", "s"}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.829983557379814*^9, 3.829983592740632*^9}, 
   3.829983639391541*^9, 3.830086772331807*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"707d4efe-0f0e-4f81-9e7b-0f11754f7491"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Kinematics", "."}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "pp", "]"}], "=", 
     SuperscriptBox["M\[Pi]", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "pm", "]"}], "=", 
     SuperscriptBox["M\[Pi]", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "p0", "]"}], "=", 
     SuperscriptBox["M\[Pi]", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "q", "]"}], "=", 
     SuperscriptBox["q", "2"]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"pp", ",", "pm"}], "]"}], "=", 
     FractionBox[
      RowBox[{"s", "-", 
       RowBox[{"SP", "[", "pp", "]"}], "-", 
       RowBox[{"SP", "[", "pm", "]"}]}], "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"pm", ",", "p0"}], "]"}], "=", 
     RowBox[{
      RowBox[{"E\[Pi]m", "*", "E\[Pi]0"}], "+", 
      RowBox[{"p1", "*", "p2", "*", "z"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"pp", ",", "p0"}], "]"}], "=", 
     RowBox[{
      RowBox[{"E\[Pi]p", "*", "E\[Pi]0"}], "-", 
      RowBox[{"p1", "*", "p2", "*", "z"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8299825768749037`*^9, 3.82998260620578*^9}, {
  3.829982653428813*^9, 3.829982658987543*^9}, {3.8299827967843943`*^9, 
  3.8299828531187763`*^9}, {3.8299837378858232`*^9, 3.8299837889738703`*^9}, {
  3.829983876551263*^9, 3.829983878178684*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"c5c459b6-e823-4183-bb54-203dc297b21d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "Mandelstam", " ", "variables", " ", "in", " ", 
     "terms", " ", "of", " ", "the", " ", "scattering", " ", "angle", " ", 
     "z"}], "=", 
    RowBox[{"cos\[Theta]", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"t", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"SP", "[", 
       RowBox[{"pm", "+", "p0"}], "]"}], "//", "ExpandScalarProduct"}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"u", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"SP", "[", 
       RowBox[{"pp", "+", "p0"}], "]"}], "//", "ExpandScalarProduct"}], "//", 
     "Simplify"}]}]}]}]], "Input",
 CellChangeTimes->{{3.829983682186377*^9, 3.829983701758608*^9}, {
  3.8299837944559183`*^9, 3.829983831006851*^9}, {3.829983863255301*^9, 
  3.8299838635274887`*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"dea1bc22-a750-42a4-beae-d3436c1cca7e"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["M\[Pi]", "2"]}], "+", 
     RowBox[{"z", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["M\[Pi]", "2"]}], "s"]}]], " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["M\[Pi]", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M\[Pi]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["q", "2"], "+", "s"}], ")"}]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["q", "2"], "-", "s"}], ")"}], "2"]}]]}], "+", 
     SuperscriptBox["q", "2"], "-", "s"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.829983791923829*^9, 3.8299838052287483`*^9}, {
   3.8299838641364613`*^9, 3.829983881731679*^9}, 3.830086772506201*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"84c80d4c-6ee9-4059-be7d-d82253b58230"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["M\[Pi]", "2"]}], "-", 
     RowBox[{"z", " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["M\[Pi]", "2"]}], "s"]}]], " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["M\[Pi]", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["M\[Pi]", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["q", "2"], "+", "s"}], ")"}]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["q", "2"], "-", "s"}], ")"}], "2"]}]]}], "+", 
     SuperscriptBox["q", "2"], "-", "s"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.829983791923829*^9, 3.8299838052287483`*^9}, {
   3.8299838641364613`*^9, 3.829983881731679*^9}, 3.830086772647614*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"83588ce3-e191-4405-a4bc-e15413d890bf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Find", " ", "the", " ", "s"}], "-", 
    RowBox[{
    "channel", " ", "scattering", " ", "angle", " ", "in", " ", "terms", " ", 
     "of", " ", "t", " ", "and", " ", 
     RowBox[{"u", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   FractionBox[
    RowBox[{"t", "-", "u"}], 
    RowBox[{"\[Sigma]\[Pi]", "*", 
     SqrtBox[
      RowBox[{"\[Lambda]", "[", 
       RowBox[{"s", ",", 
        SuperscriptBox["q", "2"], ",", 
        SuperscriptBox["M\[Pi]", "2"]}], "]"}]]}]], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.829983952153385*^9, 3.829983989853862*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"4d51fd6a-55ad-4941-aca3-77ac2fc3fa03"],

Cell[BoxData[
 FormBox["z", TraditionalForm]], "Output",
 CellChangeTimes->{3.829983990101372*^9, 3.830086772877557*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"d9567ec0-b7ef-4df4-b1dd-042526d2df81"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["e", "+"], 
     SuperscriptBox["e", "-"]}], "\[Rule]", " ", 
    RowBox[{
     SuperscriptBox["\[Pi]", "0"], "\[Gamma]"}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "4bc37b89-34b6-4572-af80-51a94d5b9d90"],
 " Cross Section"
}], "Section",
 CellChangeTimes->{{3.8300868728718367`*^9, 
  3.8300868905945187`*^9}},ExpressionUUID->"f0157345-4caa-48d7-8961-\
859b10bd291a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"RESET", " ", 
    RowBox[{"KERNEL", "!"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"<<", "FeynCalc`"}]}]], "Input",
 CellChangeTimes->{{3.829982539165934*^9, 3.8299825398041277`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"23154dd5-e435-46f2-bce0-26102fbc1ad1"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"FeynCalc \"\>", "Text",
     StripOnInput->False,
     FontWeight->Bold], "\[InvisibleSpace]", 
    StyleBox["\<\"9.3.1 (stable version). For help, use the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"documentation", " ", "center"}],
       BaseStyle->"Link",
       ButtonData:>"paclet:FeynCalc/",
       ButtonNote->"paclet:FeynCalc/"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\", check out the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["wiki",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" or visit the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"forum", "."}],
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/discussions"], None},
       ButtonNote->"http://www.feyncalc.org/forum/"],
      DisplayForm], "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["FeynCalc ", "Text", Bold], 
    Style["9.3.1 (stable version). For help, use the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "documentation center", BaseStyle -> "Link", ButtonData :> 
       "paclet:FeynCalc/", ButtonNote -> "paclet:FeynCalc/"]], "Text"], 
    Style[", check out the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["wiki", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None}, BaseStyle -> 
       "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" or visit the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["forum.", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/discussions"], None}, 
       BaseStyle -> "Hyperlink", ButtonNote -> 
       "http://www.feyncalc.org/forum/"]], "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.830087255865182*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"4d18fdd4-f4d4-40cb-a129-c3d0e0b1d560"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"To save your and our time, please check our \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["FAQ",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki/FAQ"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" for answers to some common FeynCalc questions.\"\>", "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["To save your and our time, please check our ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["FAQ", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki/FAQ"], None}, 
       BaseStyle -> "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" for answers to some common FeynCalc questions.", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.830087255871275*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"eabeea86-b93c-4c94-9b2e-d03d56ba531f"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"See also the supplied \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"examples", "."}],
       BaseStyle->"Hyperlink",
       ButtonFunction:>SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]],
       Evaluator->Automatic,
       Method->"Preemptive"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" If you use FeynCalc in your research, please cite\"\>", 
     "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["See also the supplied ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "examples.", BaseStyle -> "Hyperlink", ButtonFunction :> SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]], Evaluator -> 
       Automatic, Method -> "Preemptive"]], "Text"], 
    Style[" If you use FeynCalc in your research, please cite", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.8300872558728228`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"4705dcb8-4f2f-4bfb-9969-fe8ba1fd2b75"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, \
Comput.Phys.Commun. 256 (2020) 107478, arXiv:2001.04407.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.8300872558741283`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"acbe51f5-78fb-40c5-909f-4a048caa6280"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, \
Comput.Phys.Commun. 207 (2016) 432-444, arXiv:1601.01167.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.830087255875485*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"c32c3cac-13db-43a8-95e4-cdedae83b1cd"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] R. Mertig, M. B\[ODoubleDot]hm, and A. Denner, \
Comput. Phys. Commun. 64 (1991) 345-359.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.830087255876676*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"bb2f6068-0fc4-4bcf-9bbe-45282ca89a63"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Kinematics", "Subsection",
 CellChangeTimes->{{3.830155584481146*^9, 
  3.830155592084285*^9}},ExpressionUUID->"5c8c11f5-5dbc-435f-a1ae-\
7b368bf34bdc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Energy", " ", "and", " ", "momentum", " ", "of", " ", "the", " ", 
     "initial"}], "-", 
    RowBox[{"state", " ", 
     RowBox[{"fermions", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      SqrtBox["s"], "\[Equal]", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["me", "2"]}]], "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["me", "2"]}]]}]}], ",", "p"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pIn", "=", 
     RowBox[{
      FractionBox[
       SqrtBox["s"], "2"], 
      SqrtBox[
       RowBox[{"1", "-", 
        FractionBox[
         RowBox[{"4", 
          SuperscriptBox["me", "2"]}], "s"]}]]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["pIn", "2"], "+", 
       SuperscriptBox["me", "2"]}]], "//", "PowerExpand"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EIn", "=", 
     FractionBox[
      SqrtBox["s"], "2"]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8299827593543177`*^9, 3.8299827798226547`*^9}, {
  3.829982908132409*^9, 3.8299829160626383`*^9}, {3.829982978590568*^9, 
  3.8299831459974623`*^9}, {3.829983189019886*^9, 3.829983248464539*^9}, {
  3.8301556000005007`*^9, 3.830155696060359*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"caa8d155-10c0-464b-91bc-8a4247326730"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SqrtBox[
        RowBox[{"s", "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["me", "2"]}]}]]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SqrtBox[
        RowBox[{"s", "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["me", "2"]}]}]]}]}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.83015562374292*^9, {3.830155681318301*^9, 3.83015569957976*^9}},
 CellLabel->"Out[14]=",ExpressionUUID->"e3d48491-5252-4c30-a5f9-011e31a591c6"],

Cell[BoxData[
 FormBox[
  FractionBox[
   SqrtBox["s"], "2"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.83015562374292*^9, {3.830155681318301*^9, 3.830155699582035*^9}},
 CellLabel->"Out[16]=",ExpressionUUID->"090b410b-eeb1-4761-92fc-75b2d3888125"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Energy", " ", "and", " ", "momentum", " ", "of", " ", "the", " ", 
     "final"}], "-", 
    RowBox[{"state", " ", 
     SuperscriptBox["\[Pi]", "0"], " ", "and", " ", 
     RowBox[{"photon", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      SqrtBox["s"], "\[Equal]", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["M\[Pi]", "2"]}]], "+", 
       SqrtBox[
        SuperscriptBox["p", "2"]]}]}], ",", "p"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pOut", "=", 
     FractionBox[
      RowBox[{"s", "-", 
       SuperscriptBox["M\[Pi]", "2"]}], 
      RowBox[{"2", 
       SqrtBox["s"]}]]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["pOut", "2"], "+", 
       SuperscriptBox["M\[Pi]", "2"]}]], "//", "PowerExpand"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      SuperscriptBox["pOut", "2"]], "//", "PowerExpand"}], "//", "Simplify"}],
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E\[Pi]", "=", 
     FractionBox[
      RowBox[{"s", "+", 
       SuperscriptBox["M\[Pi]", "2"]}], 
      RowBox[{"2", 
       SqrtBox["s"]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E\[Gamma]", "=", 
     FractionBox[
      RowBox[{"s", "-", 
       SuperscriptBox["M\[Pi]", "2"]}], 
      RowBox[{"2", 
       SqrtBox["s"]}]]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8299827593543177`*^9, 3.8299827798226547`*^9}, {
  3.829982908132409*^9, 3.8299829160626383`*^9}, {3.829982978590568*^9, 
  3.8299831459974623`*^9}, {3.829983189019886*^9, 3.829983248464539*^9}, {
  3.8301556000005007`*^9, 3.830155804823161*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"e2a3d29b-a0e4-4643-a017-ac54042b2eb9"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["M\[Pi]", "2"], "-", "s"}], 
       RowBox[{"2", " ", 
        SqrtBox["s"]}]]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      FractionBox[
       RowBox[{"s", "-", 
        SuperscriptBox["M\[Pi]", "2"]}], 
       RowBox[{"2", " ", 
        SqrtBox["s"]}]]}], "}"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.8301557264608*^9, 3.830155773476457*^9, 
  3.8301558077461567`*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"867c8418-ecc3-45c6-93fb-cda3faa44cbb"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   SqrtBox[
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M\[Pi]", "2"], "+", "s"}], ")"}], "2"], "s"]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.8301557264608*^9, 3.830155773476457*^9, 
  3.830155807749913*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"84ea1c5c-bd21-4bc3-a4d6-4a86546e369d"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"s", "-", 
    SuperscriptBox["M\[Pi]", "2"]}], 
   RowBox[{"2", " ", 
    SqrtBox["s"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.8301557264608*^9, 3.830155773476457*^9, 
  3.830155807752572*^9},
 CellLabel->"Out[26]=",ExpressionUUID->"289cd3a9-a010-4130-b8d6-c0721ec2f369"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Scalar", " ", "products"}], ",", " ", 
    RowBox[{
     RowBox[{
     "where", " ", "the", " ", "angle", " ", "between", " ", "pIn", " ", 
      "and", " ", "pOut", " ", "is", " ", "given", " ", "by", " ", "z"}], "=", 
     RowBox[{"Cos", 
      RowBox[{
       RowBox[{"(", "\[Theta]", ")"}], "."}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "p0", "]"}], "=", 
     SuperscriptBox["M\[Pi]", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "p\[Gamma]", "]"}], "=", "0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "p1", "]"}], "=", 
     SuperscriptBox["me", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "p2", "]"}], "=", 
     SuperscriptBox["me", "2"]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"p1", ",", "p2"}], "]"}], "=", 
     FractionBox[
      RowBox[{"s", "-", 
       RowBox[{"2", 
        SuperscriptBox["me", "2"]}]}], "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"p0", ",", "p\[Gamma]"}], "]"}], "=", 
     FractionBox[
      RowBox[{"s", "-", 
       SuperscriptBox["M\[Pi]", "2"]}], "2"]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"p1", ",", "p0"}], "]"}], "=", 
     RowBox[{
      RowBox[{"EIn", "*", "E\[Pi]"}], "-", 
      RowBox[{"pIn", "*", "pOut", "*", "z"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"p1", ",", "p\[Gamma]"}], "]"}], "=", 
     RowBox[{
      RowBox[{"EIn", "*", "E\[Gamma]"}], "+", 
      RowBox[{"pIn", "*", "pOut", "*", "z"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"p2", ",", "p0"}], "]"}], "=", 
     RowBox[{
      RowBox[{"EIn", "*", "E\[Pi]"}], "+", 
      RowBox[{"pIn", "*", "pOut", "*", "z"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"p2", ",", "p\[Gamma]"}], "]"}], "=", 
     RowBox[{
      RowBox[{"EIn", "*", "E\[Gamma]"}], "-", 
      RowBox[{"pIn", "*", "pOut", "*", "z"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8300872502733707`*^9, 3.830087277620655*^9}, {
  3.83015510352836*^9, 3.830155150841066*^9}, {3.83015575254734*^9, 
  3.830155754881048*^9}, {3.830155810978654*^9, 3.83015590464102*^9}, {
  3.830156006573104*^9, 3.830156011942576*^9}, {3.830156310106358*^9, 
  3.830156338894623*^9}, {3.830156651344117*^9, 3.830156664703279*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"0aa85eea-295a-42eb-a760-079af691d9e3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"The", " ", "spin"}], "-", 
    RowBox[{"averaged", " ", "matrix", " ", "element", " ", 
     RowBox[{"squared", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"MSq", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], 
      RowBox[{"DiracTrace", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"GS", "[", "p2", "]"}], "-", "me"}], ")"}], ".", 
        RowBox[{"GA", "[", "\[Mu]", "]"}], ".", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"GS", "[", "p1", "]"}], "+", "me"}], ")"}], ".", 
        RowBox[{"GA", "[", "\[Mu]2", "]"}]}], "]"}], 
      RowBox[{"LC", "[", 
       RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Beta]"}], 
       "]"}], 
      RowBox[{"LC", "[", 
       RowBox[{"\[Mu]2", ",", "\[Nu]2", ",", "\[Alpha]2", ",", "\[Beta]2"}], 
       "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{"p0", ",", "\[Alpha]"}], "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{"p\[Gamma]", ",", "\[Beta]"}], "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{"p0", ",", "\[Alpha]2"}], "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{"p\[Gamma]", ",", "\[Beta]2"}], "]"}], 
      RowBox[{"(", 
       RowBox[{"-", 
        RowBox[{"MT", "[", 
         RowBox[{"\[Nu]", ",", "\[Nu]2"}], "]"}]}], ")"}]}], "//", 
     "Contract"}], "//", "DiracSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.83008690371453*^9, 3.830087033053853*^9}, {
  3.830087200340858*^9, 3.8300872186354647`*^9}, {3.83008728526466*^9, 
  3.830087366246151*^9}, {3.830155053559043*^9, 3.830155065177915*^9}, {
  3.8301559187157373`*^9, 3.830155930097972*^9}, {3.8301565796252003`*^9, 
  3.830156613825348*^9}, {3.830156715991089*^9, 3.830156718353613*^9}},
 CellLabel->"In[97]:=",ExpressionUUID->"1dd15768-79fa-424e-99c4-65d3d64d626d"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox["M\[Pi]", "4"], " ", 
    SuperscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"s", "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["me", "2"]}]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["me", "2"], " ", 
     SuperscriptBox["M\[Pi]", "4"]}], "2"], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SuperscriptBox["M\[Pi]", "2"], " ", "s", " ", 
    SuperscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"s", "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["me", "2"]}]}], ")"}]}], "-", 
   RowBox[{
    SuperscriptBox["me", "2"], " ", 
    SuperscriptBox["M\[Pi]", "2"], " ", "s"}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox["s", "2"], " ", 
    SuperscriptBox["z", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"s", "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["me", "2"]}]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["me", "2"], " ", 
     SuperscriptBox["s", "2"]}], "2"], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["M\[Pi]", "4"], " ", "s"}], "8"], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["M\[Pi]", "2"], " ", 
     SuperscriptBox["s", "2"]}], "4"], "+", 
   FractionBox[
    SuperscriptBox["s", "3"], "8"]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.8300870174406633`*^9, 3.830087033814633*^9}, 
   3.830155067613915*^9, 3.8301551522829247`*^9, {3.830155907316751*^9, 
   3.830155931542268*^9}, 3.830156013649015*^9, 3.830156584021193*^9, 
   3.830156614466215*^9, {3.830156657587535*^9, 3.830156666368037*^9}, 
   3.830156718848832*^9},
 CellLabel->"Out[97]=",ExpressionUUID->"d1db4c5a-b56e-41fe-9a09-a306531432f1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "cross", " ", 
    RowBox[{"section", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"\[Sigma]", "=", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"32", "\[Pi]", " ", "s"}]], 
      FractionBox["pOut", "pIn"], 
      RowBox[{"Integrate", "[", 
       RowBox[{"MSq", ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], "//", 
     "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Sigma]", "/.", 
     RowBox[{"{", 
      RowBox[{"me", "\[Rule]", "0"}], "}"}]}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.830155934727727*^9, 3.8301560408824053`*^9}, {
  3.830156393793515*^9, 3.830156449734969*^9}, {3.830156539656835*^9, 
  3.8301565460495567`*^9}},
 CellLabel->"In[98]:=",ExpressionUUID->"a6eb97a2-3b4e-4b99-9a4e-0914f512a067"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["me", "2"]}], "+", "s"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"s", "-", 
       SuperscriptBox["M\[Pi]", "2"]}], ")"}], "3"]}], 
   RowBox[{"96", " ", "\[Pi]", " ", 
    SuperscriptBox["s", "2"], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"4", " ", 
        SuperscriptBox["me", "2"]}], "s"]}]]}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.830155988175716*^9, 3.8301560411583776`*^9}, {
   3.8301563961636753`*^9, 3.830156420061461*^9}, 3.830156450277441*^9, 
   3.830156547333498*^9, {3.830156610484326*^9, 3.8301566153193407`*^9}, {
   3.830156658675201*^9, 3.8301566674449244`*^9}, 3.830156719828429*^9},
 CellLabel->"Out[98]=",ExpressionUUID->"e3fae44d-7659-4a25-add3-1d7e7d62aa32"],

Cell[BoxData[
 FormBox[
  FractionBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"s", "-", 
      SuperscriptBox["M\[Pi]", "2"]}], ")"}], "3"], 
   RowBox[{"96", " ", "\[Pi]", " ", "s"}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.830155988175716*^9, 3.8301560411583776`*^9}, {
   3.8301563961636753`*^9, 3.830156420061461*^9}, 3.830156450277441*^9, 
   3.830156547333498*^9, {3.830156610484326*^9, 3.8301566153193407`*^9}, {
   3.830156658675201*^9, 3.8301566674449244`*^9}, 3.830156719830785*^9},
 CellLabel->"Out[99]=",ExpressionUUID->"ecce6240-1f01-42c2-b395-fa265380bbc8"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Two - Photon Decay (Normalization for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Pi]", "0"], "\[Rule]", 
    RowBox[{
     SuperscriptBox["e", "+"], 
     SuperscriptBox["e", "-"], "\[Gamma]", " "}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "35257ea5-3c3f-4daf-9757-9665cdf1f04c"],
 "Dalitz Decay)"
}], "Section",
 CellChangeTimes->{{3.830240343292541*^9, 3.8302403646045713`*^9}, {
  3.830240790668098*^9, 
  3.830240803461176*^9}},ExpressionUUID->"8f8a262b-c796-433e-b244-\
76efeb8441a3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"RESET", " ", 
    RowBox[{"KERNEL", "!"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"<<", "FeynCalc`"}]}]], "Input",
 CellChangeTimes->{{3.829982539165934*^9, 3.8299825398041277`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"e337512a-21e5-4a4b-a5e4-56245a0774a1"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"FeynCalc \"\>", "Text",
     StripOnInput->False,
     FontWeight->Bold], "\[InvisibleSpace]", 
    StyleBox["\<\"9.3.1 (stable version). For help, use the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"documentation", " ", "center"}],
       BaseStyle->"Link",
       ButtonData:>"paclet:FeynCalc/",
       ButtonNote->"paclet:FeynCalc/"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\", check out the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["wiki",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" or visit the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"forum", "."}],
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/discussions"], None},
       ButtonNote->"http://www.feyncalc.org/forum/"],
      DisplayForm], "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["FeynCalc ", "Text", Bold], 
    Style["9.3.1 (stable version). For help, use the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "documentation center", BaseStyle -> "Link", ButtonData :> 
       "paclet:FeynCalc/", ButtonNote -> "paclet:FeynCalc/"]], "Text"], 
    Style[", check out the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["wiki", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None}, BaseStyle -> 
       "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" or visit the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["forum.", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/discussions"], None}, 
       BaseStyle -> "Hyperlink", ButtonNote -> 
       "http://www.feyncalc.org/forum/"]], "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.8302408671432858`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"98161436-b7b8-4ece-a907-7f61d84cb951"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"To save your and our time, please check our \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["FAQ",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki/FAQ"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" for answers to some common FeynCalc questions.\"\>", "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["To save your and our time, please check our ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["FAQ", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki/FAQ"], None}, 
       BaseStyle -> "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" for answers to some common FeynCalc questions.", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.830240867149618*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"d33b1d0a-522c-4e80-8d85-cb0c2f95fcf5"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"See also the supplied \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"examples", "."}],
       BaseStyle->"Hyperlink",
       ButtonFunction:>SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]],
       Evaluator->Automatic,
       Method->"Preemptive"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" If you use FeynCalc in your research, please cite\"\>", 
     "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["See also the supplied ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "examples.", BaseStyle -> "Hyperlink", ButtonFunction :> SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]], Evaluator -> 
       Automatic, Method -> "Preemptive"]], "Text"], 
    Style[" If you use FeynCalc in your research, please cite", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.8302408671516027`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"0c09f542-16a8-4f4d-bed0-93cfc484a762"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, \
Comput.Phys.Commun. 256 (2020) 107478, arXiv:2001.04407.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.830240867153481*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"dd896187-992f-43fa-a788-9f17c202f9e8"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, \
Comput.Phys.Commun. 207 (2016) 432-444, arXiv:1601.01167.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.830240867155143*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"828d9091-c962-412d-8756-53de891553dc"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] R. Mertig, M. B\[ODoubleDot]hm, and A. Denner, \
Comput. Phys. Commun. 64 (1991) 345-359.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.8302408671568213`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"ef07fc0d-c4de-4382-95ac-2ddb07cba65d"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Momentum", " ", "of", " ", "the", " ", "outgoing", " ", 
    RowBox[{"photons", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"M\[Pi]", "==", 
      RowBox[{
       SqrtBox[
        SuperscriptBox["p", "2"]], "+", 
       SqrtBox[
        SuperscriptBox["p", "2"]]}]}], ",", "p"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p\[Gamma]", "=", 
     FractionBox["M\[Pi]", "2"]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.830240629773349*^9, 3.830240670197687*^9}, {
  3.830240728984375*^9, 3.830240737988257*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"26ab3d01-5326-40ed-a97f-19c01f5cf5e8"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["M\[Pi]", "2"]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      FractionBox["M\[Pi]", "2"]}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.830240670672224*^9, 3.830240738228074*^9, 
  3.830240867674658*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"43f86045-b78b-49e8-bff1-f928142a206a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Scalar", " ", 
    RowBox[{"products", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"q1", ",", "q2"}], "]"}], "=", 
     FractionBox[
      SuperscriptBox["M\[Pi]", "2"], "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "q1", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "q2", "]"}], "=", "0"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8302405329408503`*^9, 3.830240562501041*^9}, {
  3.8302406262138777`*^9, 3.830240628570607*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"e56f1329-de21-4164-a9e0-4954363bcd15"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"We", " ", "calculate", " ", "the", " ", "two"}], "-", 
     RowBox[{"photon", " ", "decay", " ", "width", " ", 
      SuperscriptBox["\[Pi]", "0"]}]}], "\[Rule]", 
    RowBox[{
    "\[Gamma]\[Gamma]", " ", "to", " ", "normalize", " ", "the", " ", "decay",
      " ", "width", " ", "of", " ", "the", " ", "Dalitz", " ", "decay", " ", 
     "to", " ", "this", " ", 
     RowBox[{"quantity", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"MSq\[Pi]2\[Gamma]", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"LC", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Beta]"}], "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{"q1", ",", "\[Alpha]"}], "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{"q2", ",", "\[Beta]"}], "]"}], 
     RowBox[{"LC", "[", 
      RowBox[{"\[Mu]2", ",", "\[Nu]2", ",", "\[Alpha]2", ",", "\[Beta]2"}], 
      "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{"q1", ",", "\[Alpha]2"}], "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{"q2", ",", "\[Beta]2"}], "]"}], 
     RowBox[{"(", 
      RowBox[{"-", 
       RowBox[{"MT", "[", 
        RowBox[{"\[Mu]", ",", "\[Mu]2"}], "]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"-", 
       RowBox[{"MT", "[", 
        RowBox[{"\[Nu]", ",", "\[Nu]2"}], "]"}]}], ")"}]}], "//", 
    "Contract"}]}]}]], "Input",
 CellChangeTimes->{{3.830240367353772*^9, 3.830240396101198*^9}, {
  3.830240442972063*^9, 3.8302405317668447`*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"1fb4ce38-1a70-4a84-8899-d0d9b39dc4c6"],

Cell[BoxData[
 FormBox[
  FractionBox[
   SuperscriptBox["M\[Pi]", "4"], "2"], TraditionalForm]], "Output",
 CellChangeTimes->{3.830240511587473*^9, 3.8302405641720047`*^9, 
  3.830240870801198*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"85ad1907-5b46-4ed2-beb3-7e1ca1a19792"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Decay", " ", "width"}], ",", " ", 
    RowBox[{"symmetry", " ", "factor", " ", 
     RowBox[{"1", "/", "2"}], " ", "from", " ", "the", " ", "two", " ", 
     "photons"}], " ", "\[LongDash]", " ", 
    RowBox[{
     RowBox[{"note", " ", "that", " ", "F", 
      RowBox[{"(", 
       RowBox[{"0", ",", "0"}], ")"}]}], "=", 
     RowBox[{"F\[Pi]\[Gamma]\[Gamma]", "."}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"\[CapitalGamma]\[Pi]2\[Gamma]", "=", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], 
     FractionBox["p\[Gamma]", 
      RowBox[{"8", "\[Pi]", " ", 
       SuperscriptBox["M\[Pi]", "2"]}]], "MSq\[Pi]2\[Gamma]"}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.83024067821882*^9, 3.830240707497499*^9}, {
  3.8302407434786797`*^9, 3.830240770659453*^9}, {3.83024088458377*^9, 
  3.830240890996908*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"2072682d-b85f-4b37-959a-6094d713ffe2"],

Cell[BoxData[
 FormBox[
  FractionBox[
   SuperscriptBox["M\[Pi]", "3"], 
   RowBox[{"64", " ", "\[Pi]"}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.830240770937234*^9, 3.830240907414213*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"e205ef6b-f24d-4f16-ae48-9c5602aeae7b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Dalitz Decay ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Pi]", "0"], "\[Rule]", 
    RowBox[{
     SuperscriptBox["e", "+"], 
     SuperscriptBox["e", "-"], "\[Gamma]"}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "1631eb42-19ee-4e7f-8e2f-95ae8a77b937"]
}], "Section",
 CellChangeTimes->{{3.830239983480932*^9, 
  3.830240010893903*^9}},ExpressionUUID->"558b1fb7-23bd-453d-8989-\
9963460473dd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"RESET", " ", 
    RowBox[{"KERNEL", "!"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"<<", "FeynCalc`"}]}]], "Input",
 CellChangeTimes->{{3.829982539165934*^9, 3.8299825398041277`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"17db5fa2-9fe2-4dec-9c72-3981c9f4c480"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"FeynCalc \"\>", "Text",
     StripOnInput->False,
     FontWeight->Bold], "\[InvisibleSpace]", 
    StyleBox["\<\"9.3.1 (stable version). For help, use the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"documentation", " ", "center"}],
       BaseStyle->"Link",
       ButtonData:>"paclet:FeynCalc/",
       ButtonNote->"paclet:FeynCalc/"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\", check out the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["wiki",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" or visit the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"forum", "."}],
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/discussions"], None},
       ButtonNote->"http://www.feyncalc.org/forum/"],
      DisplayForm], "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["FeynCalc ", "Text", Bold], 
    Style["9.3.1 (stable version). For help, use the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "documentation center", BaseStyle -> "Link", ButtonData :> 
       "paclet:FeynCalc/", ButtonNote -> "paclet:FeynCalc/"]], "Text"], 
    Style[", check out the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["wiki", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None}, BaseStyle -> 
       "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" or visit the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["forum.", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/discussions"], None}, 
       BaseStyle -> "Hyperlink", ButtonNote -> 
       "http://www.feyncalc.org/forum/"]], "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.830087255865182*^9, 3.830242241549687*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"eeae06aa-c0c7-4803-88df-2c5fb03d18ef"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"To save your and our time, please check our \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["FAQ",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki/FAQ"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" for answers to some common FeynCalc questions.\"\>", "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["To save your and our time, please check our ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["FAQ", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki/FAQ"], None}, 
       BaseStyle -> "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" for answers to some common FeynCalc questions.", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.830087255865182*^9, 3.8302422415555773`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"afebb7f4-e2cd-4b9f-b7f3-5c3d916e5286"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"See also the supplied \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"examples", "."}],
       BaseStyle->"Hyperlink",
       ButtonFunction:>SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]],
       Evaluator->Automatic,
       Method->"Preemptive"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" If you use FeynCalc in your research, please cite\"\>", 
     "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["See also the supplied ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "examples.", BaseStyle -> "Hyperlink", ButtonFunction :> SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]], Evaluator -> 
       Automatic, Method -> "Preemptive"]], "Text"], 
    Style[" If you use FeynCalc in your research, please cite", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.830087255865182*^9, 3.83024224155709*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"fc86cb5c-24dd-4aaa-a02b-9567a458a0bf"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, \
Comput.Phys.Commun. 256 (2020) 107478, arXiv:2001.04407.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.830087255865182*^9, 3.830242241558361*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"645797b9-f31b-4c65-81ef-b279fb796e0b"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, \
Comput.Phys.Commun. 207 (2016) 432-444, arXiv:1601.01167.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.830087255865182*^9, 3.830242241559552*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"c095f44d-a99a-4aae-b229-e9c1a0209e7d"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] R. Mertig, M. B\[ODoubleDot]hm, and A. Denner, \
Comput. Phys. Commun. 64 (1991) 345-359.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.830087255865182*^9, 3.83024224156147*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"33ac204f-950a-4723-b83b-26ad84ed5555"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Kinematics", "Subsection",
 CellChangeTimes->{{3.830155584481146*^9, 
  3.830155592084285*^9}},ExpressionUUID->"a11f6d92-6105-463f-a276-\
f808dbe26569"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Two", " ", "photon", " ", "decay", " ", "width", " ", "as", " ", 
    "calculated", " ", 
    RowBox[{"above", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"\[CapitalGamma]2\[Gamma]", "=", 
    RowBox[{
     FractionBox[
      SuperscriptBox["M\[Pi]", "3"], 
      RowBox[{"64", " ", "\[Pi]"}]], 
     SuperscriptBox["F\[Pi]\[Gamma]\[Gamma]", "2"]}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.830242682390167*^9, 3.8302427018303537`*^9}, {
  3.830242895429956*^9, 3.830242895675209*^9}, {3.8302446622924623`*^9, 
  3.830244665864626*^9}},ExpressionUUID->"f6b11188-94c2-42cf-8688-\
c599ab4106fb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Scalar", " ", 
    RowBox[{"products", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "p0", "]"}], "=", 
     SuperscriptBox["M\[Pi]", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "p\[Gamma]", "]"}], "=", "0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "p1", "]"}], "=", 
     SuperscriptBox["me", "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "p2", "]"}], "=", 
     SuperscriptBox["me", "2"]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p0", "=", 
     RowBox[{"p1", "+", "p2", "+", "p\[Gamma]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"p1", ",", "p2"}], "]"}], "=", 
     FractionBox[
      RowBox[{"s12", "-", 
       RowBox[{"2", 
        SuperscriptBox["me", "2"]}]}], "2"]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"p1", ",", "p\[Gamma]"}], "]"}], "=", 
     FractionBox[
      RowBox[{
       RowBox[{"SP", "[", "p0", "]"}], "-", 
       RowBox[{"2", 
        SuperscriptBox["me", "2"]}], "-", 
       RowBox[{"2", 
        RowBox[{"SP", "[", 
         RowBox[{"p1", ",", "p2"}], "]"}]}], "-", 
       RowBox[{"2", 
        RowBox[{"SP", "[", 
         RowBox[{"p2", ",", "p\[Gamma]"}], "]"}]}]}], "2"]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"p2", ",", "p\[Gamma]"}], "]"}], "=", 
     FractionBox[
      RowBox[{"s23", "-", 
       SuperscriptBox["me", "2"]}], "2"]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8300872502733707`*^9, 3.830087277620655*^9}, {
  3.83015510352836*^9, 3.830155150841066*^9}, {3.83015575254734*^9, 
  3.830155754881048*^9}, {3.830155810978654*^9, 3.83015590464102*^9}, {
  3.830156006573104*^9, 3.830156011942576*^9}, {3.830156310106358*^9, 
  3.830156338894623*^9}, {3.830156651344117*^9, 3.830156664703279*^9}, {
  3.8302424129227943`*^9, 3.830242480844726*^9}, {3.830242539569559*^9, 
  3.8302425700083513`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"f1e7e96a-c68b-4c07-ab4a-008fac03e242"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"The", " ", "spin"}], "-", 
    RowBox[{"averaged", " ", "matrix", " ", "element", " ", 
     RowBox[{"squared", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"MSq", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"DiracTrace", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"GS", "[", "p1", "]"}], "+", "me"}], ")"}], ".", 
        RowBox[{"GA", "[", "\[Mu]", "]"}], ".", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"GS", "[", "p2", "]"}], "-", "me"}], ")"}], ".", 
        RowBox[{"GA", "[", "\[Mu]2", "]"}]}], "]"}], 
      RowBox[{"LC", "[", 
       RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Beta]"}], 
       "]"}], 
      RowBox[{"LC", "[", 
       RowBox[{"\[Mu]2", ",", "\[Nu]2", ",", "\[Alpha]2", ",", "\[Beta]2"}], 
       "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{"p0", ",", "\[Alpha]"}], "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{"p\[Gamma]", ",", "\[Beta]"}], "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{"p0", ",", "\[Alpha]2"}], "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{"p\[Gamma]", ",", "\[Beta]2"}], "]"}], 
      RowBox[{"(", 
       RowBox[{"-", 
        RowBox[{"MT", "[", 
         RowBox[{"\[Nu]", ",", "\[Nu]2"}], "]"}]}], ")"}]}], "//", 
     "Contract"}], "//", "DiracSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.83008690371453*^9, 3.830087033053853*^9}, {
  3.830087200340858*^9, 3.8300872186354647`*^9}, {3.83008728526466*^9, 
  3.830087366246151*^9}, {3.830155053559043*^9, 3.830155065177915*^9}, {
  3.8301559187157373`*^9, 3.830155930097972*^9}, {3.8301565796252003`*^9, 
  3.830156613825348*^9}, {3.830156715991089*^9, 3.830156718353613*^9}, {
  3.830242237739477*^9, 3.830242249216948*^9}, {3.8302429855036077`*^9, 
  3.8302429870772057`*^9}, {3.830243102701964*^9, 3.830243105818678*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"57e26915-31ec-44e1-99b6-29d012148f49"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["me", "4"], " ", "s12"}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["me", "2"], " ", 
    SuperscriptBox["M\[Pi]", "4"]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["me", "2"], " ", 
    SuperscriptBox["M\[Pi]", "2"], " ", "s12"}], "-", 
   RowBox[{"4", " ", 
    SuperscriptBox["me", "2"], " ", "s12", " ", "s23"}], "+", 
   RowBox[{
    SuperscriptBox["M\[Pi]", "4"], " ", "s12"}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["M\[Pi]", "2"], " ", 
    SuperscriptBox["s12", "2"]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["M\[Pi]", "2"], " ", "s12", " ", "s23"}], "+", 
   SuperscriptBox["s12", "3"], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["s12", "2"], " ", "s23"}], "+", 
   RowBox[{"2", " ", "s12", " ", 
    SuperscriptBox["s23", "2"]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.8300870174406633`*^9, 3.830087033814633*^9}, 
   3.830155067613915*^9, 3.8301551522829247`*^9, {3.830155907316751*^9, 
   3.830155931542268*^9}, 3.830156013649015*^9, 3.830156584021193*^9, 
   3.830156614466215*^9, {3.830156657587535*^9, 3.830156666368037*^9}, 
   3.830156718848832*^9, 3.8302422638062773`*^9, {3.830242561747828*^9, 
   3.830242571545909*^9}, 3.830242989047832*^9, 3.830243106524414*^9},
 CellLabel->"Out[36]=",ExpressionUUID->"e9751c4d-35a3-4624-8f47-2c3d8fd15420"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Integration", " ", "boundaries", " ", "for", " ", "s23"}], ",", 
    " ", 
    RowBox[{
     RowBox[{"see", " ", "<", 
      RowBox[{"https", ":"}]}], "//", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"pdg", ".", "lbl", ".", "gov"}], "/", "2019"}], "/", 
         "reviews"}], "/", "rpp2018"}], "-", "rev", "-", 
       RowBox[{"kinematics", ".", "pdf"}]}], ">", "."}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"E2", "=", 
     RowBox[{
      FractionBox["s12", 
       RowBox[{"2", 
        SqrtBox["s12"]}]], "//", "Simplify"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E3", "=", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["M\[Pi]", "2"], "-", "s12"}], 
       RowBox[{"2", 
        SqrtBox["s12"]}]], "//", "Simplify"}]}], ";"}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"s23Min", "=", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"E2", "+", "E3"}], ")"}], "2"], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SqrtBox[
           RowBox[{
            SuperscriptBox["E2", "2"], "-", 
            SuperscriptBox["me", "2"]}]], "+", 
          SqrtBox[
           SuperscriptBox["E3", "2"]]}], ")"}], "2"]}], "//", "Simplify"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"s23Max", "=", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"E2", "+", "E3"}], ")"}], "2"], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SqrtBox[
           RowBox[{
            SuperscriptBox["E2", "2"], "-", 
            SuperscriptBox["me", "2"]}]], "-", 
          SqrtBox[
           SuperscriptBox["E3", "2"]]}], ")"}], "2"]}], "//", "Simplify"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8302427326403227`*^9, 3.830242824369299*^9}, {
  3.830243133412181*^9, 3.830243164616662*^9}, {3.8302431965614643`*^9, 
  3.8302432060495157`*^9}},
 CellLabel->"In[58]:=",ExpressionUUID->"6c26102b-b8f8-422e-8d40-7e0bf8891239"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"The", " ", "differential", " ", "decay", " ", "width"}], ",", 
    " ", 
    RowBox[{
     RowBox[{
     "integrated", " ", "over", " ", "s23", " ", "and", " ", "normalized", 
      " ", "to", " ", "the", " ", "two"}], "-", 
     RowBox[{"photon", " ", "decay", " ", 
      RowBox[{"width", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"\[CapitalGamma]\[Pi]ee\[Gamma]dqSq", "=", 
   RowBox[{
    RowBox[{
     FractionBox["1", "\[CapitalGamma]2\[Gamma]"], 
     FractionBox["1", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"2", "\[Pi]"}], ")"}], "3"]], 
     FractionBox["1", 
      RowBox[{"32", 
       SuperscriptBox["M\[Pi]", "3"]}]], 
     RowBox[{"Integrate", "[", 
      RowBox[{"MSq", ",", 
       RowBox[{"{", 
        RowBox[{"s23", ",", "s23Min", ",", "s23Max"}], "}"}]}], "]"}]}], "//",
     "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.830155934727727*^9, 3.8301560408824053`*^9}, {
  3.830156393793515*^9, 3.830156449734969*^9}, {3.830156539656835*^9, 
  3.8301565460495567`*^9}, {3.830242599165245*^9, 3.830242673083313*^9}, {
  3.830242705886462*^9, 3.830242723022813*^9}, {3.830242827703938*^9, 
  3.830242830358652*^9}, {3.830242873901699*^9, 3.830242874399434*^9}, {
  3.830244307382503*^9, 3.830244313976276*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"1dcc7478-7208-4fa2-b4b3-babb970d0f5e"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"s12", " ", 
    SqrtBox[
     RowBox[{"s12", "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["me", "2"]}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["me", "2"]}], "+", "s12"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["M\[Pi]", "2"], "-", "s12"}], ")"}], "2"], "s12"], 
      ")"}], 
     RowBox[{"3", "/", "2"}]]}], 
   RowBox[{"6", " ", 
    SuperscriptBox["\[Pi]", "2"], " ", 
    SuperscriptBox["F\[Pi]\[Gamma]\[Gamma]", "2"], " ", 
    SuperscriptBox["M\[Pi]", "6"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.830155988175716*^9, 3.8301560411583776`*^9}, {
   3.8301563961636753`*^9, 3.830156420061461*^9}, 3.830156450277441*^9, 
   3.830156547333498*^9, {3.830156610484326*^9, 3.8301566153193407`*^9}, {
   3.830156658675201*^9, 3.8301566674449244`*^9}, 3.830156719828429*^9, {
   3.830242638060808*^9, 3.8302426430074177`*^9}, 3.830242832415186*^9, 
   3.830242877297818*^9, 3.830242908340068*^9, 3.830243113107841*^9, 
   3.8302431551357193`*^9, {3.830243201857271*^9, 3.830243207442851*^9}, {
   3.830244308003764*^9, 3.830244314486208*^9}},
 CellLabel->"Out[64]=",ExpressionUUID->"624be7eb-033d-4d62-b2e2-0d16e6bf7529"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 647},
WindowMargins->{{232, Automatic}, {Automatic, 0}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 197, 3, 159, "Title",ExpressionUUID->"93ce0d35-dd3a-459f-a7f3-9ffe3063cc0e"],
Cell[780, 27, 973, 26, 84, "Input",ExpressionUUID->"84020e94-1db8-42af-a5c8-6de4d0279412"],
Cell[CellGroupData[{
Cell[1778, 57, 328, 7, 63, "Input",ExpressionUUID->"2809d165-2007-4043-b67d-18f0e7d2f2a6"],
Cell[CellGroupData[{
Cell[2131, 68, 2481, 67, 30, "Print",ExpressionUUID->"273b65a6-5f0e-47e6-aaf8-21811d06a14d"],
Cell[4615, 137, 1231, 30, 30, "Print",ExpressionUUID->"ecd34515-9d8f-4c55-a03e-e98fd91d5567"],
Cell[5849, 169, 1235, 33, 30, "Print",ExpressionUUID->"7d6a6b06-e0e3-457e-8f13-8198c8975ac7"],
Cell[7087, 204, 387, 8, 27, "Print",ExpressionUUID->"1b5bcf7c-b03b-42e5-b0f6-49e15cde755e"],
Cell[7477, 214, 388, 8, 27, "Print",ExpressionUUID->"6e9ebe7a-7040-4f8d-8b4f-f0b1e0a6ba83"],
Cell[7868, 224, 375, 8, 27, "Print",ExpressionUUID->"ef05325c-13a2-4544-9f4c-a69aa4aa36cb"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8292, 238, 407, 12, 70, "Section",ExpressionUUID->"7e654cb2-248a-41b6-b95f-d61ef179bdca"],
Cell[CellGroupData[{
Cell[8724, 254, 160, 3, 34, "Subsection",ExpressionUUID->"ee42434f-6dde-4689-8939-f31ef28d34db"],
Cell[8887, 259, 983, 27, 128, "Input",ExpressionUUID->"3ac2013f-691e-4b7c-b6a4-7b61ded813ab"],
Cell[CellGroupData[{
Cell[9895, 290, 2302, 71, 331, "Input",ExpressionUUID->"4c9aa8a3-5f60-4ded-8ecf-f4e5ab1964bf"],
Cell[12200, 363, 1552, 43, 69, "Output",ExpressionUUID->"5268f882-fbcb-4f44-aa74-286518434564"],
Cell[13755, 408, 594, 17, 74, "Output",ExpressionUUID->"e47306e2-45da-4931-aa20-d694696d1300"],
Cell[14352, 427, 567, 16, 74, "Output",ExpressionUUID->"7f6ac029-8b1c-4d02-b7ed-4b82f3cab11d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14956, 448, 1526, 49, 280, "Input",ExpressionUUID->"0d976fc8-d16c-4fff-97bf-d3dc400cc467"],
Cell[16485, 499, 772, 25, 57, "Output",ExpressionUUID->"596cddea-c1fd-4b99-8c3d-55e9438beff0"],
Cell[17260, 526, 288, 7, 60, "Output",ExpressionUUID->"65d6c7f6-9353-44b8-955a-002fdc323022"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17597, 539, 260, 5, 34, "Subsection",ExpressionUUID->"63056678-6135-4f39-b2b6-9210ee4bd9c5"],
Cell[CellGroupData[{
Cell[17882, 548, 1078, 31, 100, "Input",ExpressionUUID->"3eedcbfc-4366-459d-9864-e3b9a141b64c"],
Cell[18963, 581, 404, 11, 57, "Output",ExpressionUUID->"fbc2d560-8ade-4aca-bfa7-b0cfe97e2938"],
Cell[19370, 594, 750, 25, 57, "Output",ExpressionUUID->"707d4efe-0f0e-4f81-9e7b-0f11754f7491"]
}, Open  ]],
Cell[20135, 622, 1769, 48, 227, "Input",ExpressionUUID->"c5c459b6-e823-4183-bb54-203dc297b21d"],
Cell[CellGroupData[{
Cell[21929, 674, 961, 25, 84, "Input",ExpressionUUID->"dea1bc22-a750-42a4-beae-d3436c1cca7e"],
Cell[22893, 701, 1036, 30, 81, "Output",ExpressionUUID->"84c80d4c-6ee9-4059-be7d-d82253b58230"],
Cell[23932, 733, 1036, 30, 81, "Output",ExpressionUUID->"83588ce3-e191-4405-a4bc-e15413d890bf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25005, 768, 742, 20, 92, "Input",ExpressionUUID->"4d51fd6a-55ad-4941-aca3-77ac2fc3fa03"],
Cell[25750, 790, 199, 3, 37, "Output",ExpressionUUID->"d9567ec0-b7ef-4df4-b1dd-042526d2df81"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26010, 800, 486, 15, 70, "Section",ExpressionUUID->"f0157345-4caa-48d7-8961-859b10bd291a"],
Cell[CellGroupData[{
Cell[26521, 819, 328, 7, 63, "Input",ExpressionUUID->"23154dd5-e435-46f2-bce0-26102fbc1ad1"],
Cell[CellGroupData[{
Cell[26874, 830, 2459, 67, 30, "Print",ExpressionUUID->"4d18fdd4-f4d4-40cb-a129-c3d0e0b1d560"],
Cell[29336, 899, 1207, 30, 30, "Print",ExpressionUUID->"eabeea86-b93c-4c94-9b2e-d03d56ba531f"],
Cell[30546, 931, 1215, 33, 30, "Print",ExpressionUUID->"4705dcb8-4f2f-4bfb-9969-fe8ba1fd2b75"],
Cell[31764, 966, 367, 8, 27, "Print",ExpressionUUID->"acbe51f5-78fb-40c5-909f-4a048caa6280"],
Cell[32134, 976, 366, 8, 27, "Print",ExpressionUUID->"c32c3cac-13db-43a8-95e4-cdedae83b1cd"],
Cell[32503, 986, 353, 8, 27, "Print",ExpressionUUID->"bb2f6068-0fc4-4bcf-9bbe-45282ca89a63"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[32905, 1000, 158, 3, 34, "Subsection",ExpressionUUID->"5c8c11f5-5dbc-435f-a1ae-7b368bf34bdc"],
Cell[CellGroupData[{
Cell[33088, 1007, 1633, 50, 255, "Input",ExpressionUUID->"caa8d155-10c0-464b-91bc-8a4247326730"],
Cell[34724, 1059, 736, 24, 57, "Output",ExpressionUUID->"e3d48491-5252-4c30-a5f9-011e31a591c6"],
Cell[35463, 1085, 259, 6, 60, "Output",ExpressionUUID->"090b410b-eeb1-4761-92fc-75b2d3888125"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35759, 1096, 1995, 60, 321, "Input",ExpressionUUID->"e2a3d29b-a0e4-4643-a017-ac54042b2eb9"],
Cell[37757, 1158, 653, 20, 64, "Output",ExpressionUUID->"867c8418-ecc3-45c6-93fb-cda3faa44cbb"],
Cell[38413, 1180, 423, 13, 74, "Output",ExpressionUUID->"84ea1c5c-bd21-4bc3-a4d6-4a86546e369d"],
Cell[38839, 1195, 336, 9, 64, "Output",ExpressionUUID->"289cd3a9-a010-4130-b8d6-c0721ec2f369"]
}, Open  ]],
Cell[39190, 1207, 2882, 83, 358, "Input",ExpressionUUID->"0aa85eea-295a-42eb-a760-079af691d9e3"],
Cell[CellGroupData[{
Cell[42097, 1294, 1867, 46, 143, "Input",ExpressionUUID->"1dd15768-79fa-424e-99c4-65d3d64d626d"],
Cell[43967, 1342, 1773, 52, 101, "Output",ExpressionUUID->"d1db4c5a-b56e-41fe-9a09-a306531432f1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45777, 1399, 940, 26, 106, "Input",ExpressionUUID->"a6eb97a2-3b4e-4b99-9a4e-0914f512a067"],
Cell[46720, 1427, 890, 23, 87, "Output",ExpressionUUID->"e3fae44d-7659-4a25-add3-1d7e7d62aa32"],
Cell[47613, 1452, 594, 12, 64, "Output",ExpressionUUID->"ecce6240-1f01-42c2-b395-fa265380bbc8"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[48268, 1471, 559, 16, 108, "Section",ExpressionUUID->"8f8a262b-c796-433e-b244-76efeb8441a3"],
Cell[CellGroupData[{
Cell[48852, 1491, 328, 7, 63, "Input",ExpressionUUID->"e337512a-21e5-4a4b-a5e4-56245a0774a1"],
Cell[CellGroupData[{
Cell[49205, 1502, 2461, 67, 30, "Print",ExpressionUUID->"98161436-b7b8-4ece-a907-7f61d84cb951"],
Cell[51669, 1571, 1207, 30, 30, "Print",ExpressionUUID->"d33b1d0a-522c-4e80-8d85-cb0c2f95fcf5"],
Cell[52879, 1603, 1215, 33, 30, "Print",ExpressionUUID->"0c09f542-16a8-4f4d-bed0-93cfc484a762"],
Cell[54097, 1638, 365, 8, 27, "Print",ExpressionUUID->"dd896187-992f-43fa-a788-9f17c202f9e8"],
Cell[54465, 1648, 366, 8, 27, "Print",ExpressionUUID->"828d9091-c962-412d-8756-53de891553dc"],
Cell[54834, 1658, 355, 8, 27, "Print",ExpressionUUID->"ef07fc0d-c4de-4382-95ac-2ddb07cba65d"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[55238, 1672, 729, 20, 113, "Input",ExpressionUUID->"26ab3d01-5326-40ed-a97f-19c01f5cf5e8"],
Cell[55970, 1694, 470, 14, 57, "Output",ExpressionUUID->"43f86045-b78b-49e8-bff1-f928142a206a"]
}, Open  ]],
Cell[56455, 1711, 740, 20, 127, "Input",ExpressionUUID->"e56f1329-de21-4164-a9e0-4954363bcd15"],
Cell[CellGroupData[{
Cell[57220, 1735, 1577, 40, 105, "Input",ExpressionUUID->"1fb4ce38-1a70-4a84-8899-d0d9b39dc4c6"],
Cell[58800, 1777, 276, 6, 60, "Output",ExpressionUUID->"85ad1907-5b46-4ed2-beb3-7e1ca1a19792"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59113, 1788, 995, 25, 102, "Input",ExpressionUUID->"2072682d-b85f-4b37-959a-6094d713ffe2"],
Cell[60111, 1815, 278, 6, 61, "Output",ExpressionUUID->"e205ef6b-f24d-4f16-ae48-9c5602aeae7b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[60438, 1827, 460, 14, 70, "Section",ExpressionUUID->"558b1fb7-23bd-453d-8989-9963460473dd"],
Cell[CellGroupData[{
Cell[60923, 1845, 328, 7, 63, "Input",ExpressionUUID->"17db5fa2-9fe2-4dec-9c72-3981c9f4c480"],
Cell[CellGroupData[{
Cell[61276, 1856, 2481, 67, 30, "Print",ExpressionUUID->"eeae06aa-c0c7-4803-88df-2c5fb03d18ef"],
Cell[63760, 1925, 1231, 30, 30, "Print",ExpressionUUID->"afebb7f4-e2cd-4b9f-b7f3-5c3d916e5286"],
Cell[64994, 1957, 1234, 33, 30, "Print",ExpressionUUID->"fc86cb5c-24dd-4aaa-a02b-9567a458a0bf"],
Cell[66231, 1992, 387, 8, 27, "Print",ExpressionUUID->"645797b9-f31b-4c65-81ef-b279fb796e0b"],
Cell[66621, 2002, 388, 8, 27, "Print",ExpressionUUID->"c095f44d-a99a-4aae-b229-e9c1a0209e7d"],
Cell[67012, 2012, 374, 8, 27, "Print",ExpressionUUID->"33ac204f-950a-4723-b83b-26ad84ed5555"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[67435, 2026, 158, 3, 34, "Subsection",ExpressionUUID->"a11f6d92-6105-463f-a276-f808dbe26569"],
Cell[67596, 2031, 681, 17, 84, "Input",ExpressionUUID->"f6b11188-94c2-42cf-8688-c599ab4106fb"],
Cell[68280, 2050, 2373, 66, 358, "Input",ExpressionUUID->"f1e7e96a-c68b-4c07-ab4a-008fac03e242"],
Cell[CellGroupData[{
Cell[70678, 2120, 1985, 47, 126, "Input",ExpressionUUID->"57e26915-31ec-44e1-99b6-29d012148f49"],
Cell[72666, 2169, 1384, 31, 64, "Output",ExpressionUUID->"e9751c4d-35a3-4624-8f47-2c3d8fd15420"]
}, Open  ]],
Cell[74065, 2203, 2227, 71, 256, "Input",ExpressionUUID->"6c26102b-b8f8-422e-8d40-7e0bf8891239"],
Cell[CellGroupData[{
Cell[76317, 2278, 1423, 34, 105, "Input",ExpressionUUID->"1dcc7478-7208-4fa2-b4b3-babb970d0f5e"],
Cell[77743, 2314, 1360, 33, 83, "Output",ExpressionUUID->"624be7eb-033d-4d62-b2e2-0d16e6bf7529"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

